#!/bin/sh
# -*-Scheme-*-
#
# Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015,
#     2016, 2017, 2018, 2019 Matthew Birkholz
#
# This file is part of a GLib plugin for MIT/GNU Scheme Pucked.
#
# This plugin is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This plugin is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this plugin; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301, USA.

# Compile the GLIB option.

set -e
: ${MIT_SCHEME_EXE=mit-scheme}
${MIT_SCHEME_EXE} --prepend-library . --batch-mode <<\EOF
(begin

  (parameterize ((param:suppress-loading-message? #t))
    (for-each load-option '(cref sos ffi)))

  (if (name->package '(glib))
      (error "The Glib package already exists."))
  (let ((package-set (package-set-pathname "glib")))
    (if (not (file-modification-time<? "glib.pkg" package-set))
	(cref/generate-trivial-constructor "glib"))
    (construct-packages-from-file (fasload package-set)))

  ;; glib.scm includes the Glib c-includes, but does not otherwise
  ;; use the FFI.
  (compile-file "glib" '("glib-const.bin") (->environment '(glib)))
  ;; Mostly to set! c-includes:
  (load "glib" (->environment '(glib)))

  ;; The wrappers use the FFI, c-includes, and some integrable
  ;; definitions in glib.scm.  Dependencies between them are
  ;; rare.
  (compile-file "gobject" '("glib") (->environment '(gobject)))
  (compile-file "gio" '("glib") (->environment '(gio)))
  (compile-file "glib-main" '("glib") (->environment '(glib main)))
  (compile-file "glib-thread" '("glib-main")
		(->environment '(glib thread)))

  (cref/generate-constructors "glib")
  )
EOF
suffix=`echo "(display (microcode-id/operating-system-suffix))" \
	| ${MIT_SCHEME_EXE} --batch-mode`
report=glib-$suffix.crf
if [ -s "$report" ]; then
    awk "{printf \"$report:%d: %s\\n\",NR,\$0}" $report
fi
